@@ -1,9 +1,11 @@
-// Copyright (C) 2008-2015 Conrad Sanderson
-// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 National ICT Australia (NICTA)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
+// -------------------------------------------------------------------
+// 
+// Written by Conrad Sanderson - http://conradsanderson.id.au
 
 
 //! \addtogroup fn_misc
@@ -36,7 +38,7 @@ linspace
   typedef typename vec_type::pod_type   T;
   
   vec_type x;
-    
+  
   if(num >= 2)
     {
     x.set_size(num);
@@ -67,8 +69,6 @@ linspace
       
       x_mem[num_m1] = eT(end);
       }
-    
-    return x;
     }
   else
     {
@@ -268,6 +268,8 @@ sympd(const Base<typename T1::elem_type,T1>& X)
   {
   arma_extra_debug_sigprint();
   
+  arma_debug_warn("sympd() is deprecated and will be removed; change inv(sympd(X)) to inv_sympd(X)");
+  
   return X.get_ref();
   }
 
@@ -357,4 +359,74 @@ null(Mat<typename T1::elem_type>& out, const Base<typename T1::elem_type, T1>& X
 
 
 
+inline
+uvec
+ind2sub(const SizeMat& s, const uword i)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (i >= (s.n_rows * s.n_cols) ), "ind2sub(): index out of range" );
+  
+  uvec out(2);
+  
+  out[0] = i % s.n_rows;
+  out[1] = i / s.n_rows;
+  
+  return out;
+  }
+
+
+
+inline
+uvec
+ind2sub(const SizeCube& s, const uword i)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (i >= (s.n_rows * s.n_cols * s.n_slices) ), "ind2sub(): index out of range" );
+  
+  const uword n_elem_slice = s.n_rows * s.n_cols;
+  
+  const uword slice  = i / n_elem_slice;
+  const uword j      = i - (slice * n_elem_slice);
+  const uword row    = j % s.n_rows;
+  const uword col    = j / s.n_rows;
+  
+  uvec out(3);
+  
+  out[0] = row;
+  out[1] = col;
+  out[2] = slice;
+  
+  return out;
+  }
+
+
+
+arma_inline
+uword
+sub2ind(const SizeMat& s, const uword row, const uword col)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( ((row >= s.n_rows) || (col >= s.n_cols)), "sub2ind(): subscript out of range" );
+  
+  return uword(row + col*s.n_rows);
+  }
+
+
+
+arma_inline
+uword
+sub2ind(const SizeCube& s, const uword row, const uword col, const uword slice)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( ((row >= s.n_rows) || (col >= s.n_cols) || (slice >= s.n_slices)), "sub2ind(): subscript out of range" );
+  
+  return uword( (slice * s.n_rows * s.n_cols) + (col * s.n_rows) + row );
+  }
+
+
+
 //! @}
